===============================
ufs_tools
===============================

.. image:: https://img.shields.io/pypi/v/ufs_tools.svg
        :target: https://pypi.python.org/pypi/ufs_tools

.. image:: https://img.shields.io/travis/weijia/ufs_tools.svg
        :target: https://travis-ci.org/weijia/ufs_tools

.. image:: https://readthedocs.org/projects/ufs_tools/badge/?version=latest
        :target: https://readthedocs.org/projects/ufs_tools/?badge=latest
        :alt: Documentation Status


Some functions can be used during python development

* Free software: ISC license
* Documentation: https://ufs_tools.readthedocs.org.

Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
